<?php
/**
 * Main functions file
 * 
 * This file is the WordPress functions.php file, which which contains many 
 * of the functions for set up and operation of the theme
 *
 * @package		Panache WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */

/* ---- Set content width --------*/
if(!isset( $content_width )) $content_width = 1600;


/* ---- load files ---------------*/ 
//require(get_template_directory() . '/includes/panache-options.php');
require(get_template_directory() . '/includes/kha-customizer.php');
require(get_template_directory() . '/includes/panache-post-functions.php');
require(get_template_directory() . '/includes/panache-custom-functions.php');
if( is_admin() ){
	require(get_template_directory() . '/includes/panache-metabox-functions.php');	
}
require(get_template_directory() . '/widgets/panache-social-widget.php');
require(get_template_directory() . '/widgets/panache-author-widget.php');
require(get_template_directory() . '/widgets/panache-categories-widget.php');
require(get_template_directory() . '/widgets/panache-recent-posts-widget.php');

/**
 *  Allows shortcodes to be displayed in sidebar text widgets
 */
add_filter('widget_text', 'do_shortcode');

/* ========================================================================================================
 *                 Scripts and Styles
 * ======================================================================================================== */
/**
 * Load jQuery Scripts
 * 
 * function to load jquery scripts. Some of the functions are conditionally loaded 
 * so that the user can disable naughty scripts
 * @uses is_admin() @uses wp_enqueue_script @uses get_template_directory_uri()
 * 
 */
if ( !function_exists ('panache_load_js')){
	function panache_load_js() {

		$disable_colorbox = intval( panache_get_option( 'panache_disable_colorboxjs' ) );
		$disable_fitvidsjs = intval( panache_get_option( 'panache_disable_fitvidsjs' ) );
		
		if(!is_admin()){
			wp_deregister_script('hoverIntent');
			wp_enqueue_script( 'hoverIntent',get_template_directory_uri() . '/js/superfish/hoverIntent.min.js', array( 'jquery' ), '' ,true);
			wp_enqueue_script( 'jquery-superfish', get_template_directory_uri() . '/js/superfish/superfish.min.js', array( 'jquery' ), '' );
			
			if ($disable_fitvidsjs != 1) {
				wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '' );
				wp_enqueue_script( 'fitvids-doc-ready', get_template_directory_uri() . '/js/fitvids-doc-ready.js', array( 'jquery' ), '' );
			}
			
			//SlickNav
			wp_enqueue_script( 'jquery-slick-nav', get_template_directory_uri() . '/js/slick-nav/jquery.slicknav.js', array( 'jquery' ), '' );
			//mobile scripts
			wp_enqueue_script( 'mobile-doc-ready', get_template_directory_uri() . '/js/mobile-doc-ready.js', array( 'jquery' ), '' );
						
			if ($disable_colorbox != 1) {
				wp_enqueue_script( 'jquery-colorbox', get_template_directory_uri() . '/js/colorbox/jquery.colorbox-min.js', array( 'jquery' ), '' );
				wp_enqueue_script( 'colorbox-doc-ready', get_template_directory_uri() . '/js/colorbox/colorbox_doc_ready.js', array( 'jquery' ), '' );
			}
			
			wp_enqueue_script( 'jquery-nivo-slider', get_template_directory_uri() . '/js/nivo-slider/jquery.nivo.slider.pack.js', array( 'jquery' ), '' );
			wp_enqueue_script( 'ka-panache-custom_js', get_template_directory_uri() . '/js/doc-ready-scripts.js', array( 'jquery' ), '' );
			
			wp_enqueue_script( 'jquery-flex-slider', get_template_directory_uri() . '/js/flex-slider/jquery.flexslider.js', array( 'jquery' ), '' );
			wp_enqueue_script( 'ka-panache-custom-flex-js', get_template_directory_uri() . '/js/flex-slider/flex-doc-ready-scripts.js', array( 'jquery' ), '' );

		}
	}
	add_action('wp_enqueue_scripts', 'panache_load_js');
}

/**
 * Load CSS Styles
 * 
 * function to load css styles. Some of the style sheets are conditionally loaded 
 * so as they are part of jQuery plugins
 * @uses panache_get_options() found in panache-options.php
 * WordPress functions - see codex
 * @uses wp_register_style() @uses wp_enqueue_style @uses get_template_directory_uri()
 * @uses get_template_directory_uri()
 * 
 */
if ( !function_exists ('panache_styles')) {
	function panache_styles() {

		wp_enqueue_style( 'panache-style',get_stylesheet_uri(),array() );
		wp_enqueue_style( 'panache_font_awesome_style',get_template_directory_uri() . '/font-awesome/css/font-awesome.min.css',array() );
		
		$ka_css = panache_custom_css();
		wp_add_inline_style( 'panache-style', $ka_css );

	}
	add_action('wp_enqueue_scripts', 'panache_styles');
}

/**
 * Load custom fonts and styles
 * 
 * WordPress functions - see codex
 * @uses get_template_directory()
 * 
 */
if ( !function_exists ('panache_setup')){// load custom styles and fonts
	function panache_setup(){
		include( get_template_directory() . '/css/panache-custom-fonts.php' );
	 }
	add_action( 'wp_enqueue_scripts', 'panache_setup' );
}

/*
********* Set up Menu in Dashboard under Appearance **************
*/
if ( !function_exists ('panache_register_menu')){
	function panache_register_menu() {
		register_nav_menu('primary-nav' ,__( 'Primary Menu' , 'panache' ) );
		register_nav_menu('secondary-nav' ,__( 'Secondary Menu' , 'panache') );
		register_nav_menu('side-nav' ,__( 'Side Menu' , 'panache') );
	}
add_action( 'init', 'panache_register_menu' );
}

/**
 * Theme Support Functions
 * 
 * This function adds all theme support functions on the after_setup_theme hook
 * See the WordPress Codex for each support
 * 
 */
if( !function_exists ('panache_theme_supports')){
	function panache_theme_supports () {
		/* ----------- post formats -------------------- */
		// ADD POST FORMATS
		add_theme_support( 'post-formats', array( 'aside', 'audio','chat', 'gallery', 'image', 'link', 'quote', 'status', 'video' ) );
		
		/* ------------editor-style -------------------- */
		add_editor_style();
		//Custom Backgrounds 
		add_theme_support('custom-background');
		//custom header
		$panache_header_args = array(
			'flex-width' => true,
			'width' => 1000,
			'flex-height' => true,
			'height' => 333,
			'header-text' => false,
			'default-image' => '',
			'uploads' => true,
		);
		add_theme_support('custom-header',$panache_header_args);
		//feeds
		add_theme_support('automatic-feed-links');
		//thumbnails
		add_theme_support('post-thumbnails');
		add_image_size('panache_wide_thumbnail',180,120,true);
		set_post_thumbnail_size( 960, 9999 );
		//enable translation
		load_theme_textdomain('panache', get_template_directory() . '/languages');
		
		//html5 markup for comment lists, comment forms, search forms and galleries.
		add_theme_support('html5' , array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ));
		
		//let WordPress look after the title tags
		add_theme_support('title-tag');
		
		//temporary load to check translation
		//load_textdomain( 'panache', get_template_directory() . '/languages/fr_FR.mo' );
	}
	add_action('after_setup_theme','panache_theme_supports');
}

/**
 * Register Side bars
 * Thanks to Justin Tadlock for the post on sidebars 
 * @link http://justintadlock.com/archives/2010/11/08/sidebars-in-wordpress
 */

if (!function_exists ( 'panache_register_sidebars' )) {
	function panache_register_sidebars() {
	// Sidebars and footer areas
	register_sidebar(array(
						'id' => 'panache_default_sidebar_a',
						'name'=>__( 'Default A', 'panache' ),
						'description' => __( 'Use for standard WordPress pages', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_default_sidebar_b',
						'name'=>__( 'Default B', 'panache' ),
						'description' => __( 'Second sidebar for standard WordPress pages', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_blog_sidebar_a',
						'name'=>__( 'Blog A', 'panache' ),
						'description' => __( 'First Blog Sidebar', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_blog_sidebar_b',
						'name'=>__( 'Blog B', 'panache' ),
						'description' => __( 'Second Blog Sidebar', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_right_header_sidebar',
						'name'=>__( 'Right Header Area', 'panache' ),
						'description' => __( 'Placed in upper right hand corner of header', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_left_header_sidebar',
						'name'=>__( 'Left Header Area', 'panache' ),
						'description' => __( 'Placed in upper left hand corner of header', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_feature_sidebar_a',
						'name'=>__( 'Feature Sidebar A', 'panache' ),
						'description' => __( 'Used in Feature Area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_feature_page_sidebar_b',
						'name'=>__( 'Feature Sidebar B', 'panache' ),
						'description' => __( 'Used in Feature Area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_feature_page_sidebar_c',
						'name'=>__( 'Feature Sidebar C', 'panache' ),
						'description' => __( 'Used in Feature Area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_feature_page_sidebar_d',
						'name'=>__( 'Feature Sidebar D', 'panache' ),
						'description' => __( 'Used in Feature Area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_404_sidebar_a',
						'name'=>__( 'Error 404 A', 'panache' ),
						'description' => __( 'Use this for your 404 page', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_404_sidebar_b',
						'name'=>__( 'Error 404 B', 'panache' ),
						'description' => __( 'Use this for your 404 page', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_contact_sidebar_a',
						'name'=>__( 'Contact A', 'panache' ),
						'description' => __( 'Use this for your Contact page', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_contact_sidebar_b',
						'name'=>__( 'Contact B', 'panache' ),
						'description' => __( 'Use this for your Contact page', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);				
	
	register_sidebar(array(
						'id' => 'panache_about_sidebar_a',
						'name'=>__( 'About A', 'panache' ),
						'description' => __( 'Use this for your About page', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_about_sidebar_b',
						'name'=>__( 'About B', 'panache' ),
						'description' => __( 'Use this for your About page', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_home_section1_sidebar',
						'name'=>__( 'Home Page Section 1', 'panache' ),
						'description' => __( 'Use as a widgetized area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_home_section3_sidebar',
						'name'=>__( 'Home Page Section 3', 'panache' ),
						'description' => __( 'Use as a widgetized area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_home_section5_sidebar',
						'name'=>__( 'Home Page Section 5', 'panache' ),
						'description' => __( 'Use as a widgetized area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_home_section7_sidebar',
						'name'=>__( 'Home Page Section 7', 'panache' ),
						'description' => __( 'Use as a widgetized area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_footer_long_sidebar',
						'name'=>__( 'Footer Full Width', 'panache' ),
						'description' => __( 'Full width footer widget area', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_footer_a_sidebar',
						'name'=>__( 'Footer-A', 'panache' ),
						'description' => __( 'First column in footer', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_footer_b_sidebar',
						'name'=>__( 'Footer-B', 'panache' ),
						'description' => __( 'Second column in footer', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);	
	register_sidebar(array(
						'id' => 'panache_footer_c_sidebar',
						'name'=>__( 'Footer-C', 'panache' ),
						'description' => __( 'Third column in footer', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);	
	register_sidebar(array(
						'id' => 'panache_footer_d_sidebar',
						'name'=>__( 'Footer-D', 'panache' ),
						'description' => __( 'Fourth column in footer', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);						
	register_sidebar(array(
						'id' => 'panache_sidebar_1',
						'name'=>__( 'Sidebar 1', 'panache' ),
						'description' => __( 'Use for your custom pages', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_sidebar_2',
						'name'=>__( 'Sidebar 2', 'panache' ),
						'description' => __( 'Use for your custom pages', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_sidebar_3',
						'name'=>__( 'Sidebar 3', 'panache' ),
						'description' => __( 'Use for your custom pages', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_sidebar_4',
						'name'=>__( 'Sidebar 4', 'panache' ),
						'description' => __( 'Use for your custom pages', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_sidebar_5',
						'name'=>__( 'Sidebar 5', 'panache' ),
						'description' => __( 'Use for your custom pages', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	register_sidebar(array(
						'id' => 'panache_sidebar_6',
						'name'=>__( 'Sidebar 6', 'panache' ),
						'description' => __( 'Use for your custom pages', 'panache' ),
						'before_widget' => '<div id="%1$s" class="widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h3 class="widget-title">',
						'after_title' => '</h3>'
						)
					);
	}
	add_action( 'widgets_init', 'panache_register_sidebars' );
}

/* ========================================================================================================
 *              Comments and Pingbacks
 * ======================================================================================================== */
/**
 * Javascript setup for threaded comments
 */
if ( !function_exists ('panache_enqueue_comment_reply_script')){
	function panache_enqueue_comment_reply_script() {
		if (is_singular() && comments_open() && (get_option('thread_comments') == 1)) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'panache_enqueue_comment_reply_script' );
}