<?php
/**
 * Custom functions file for adding Panache metabox to page panels
 * 
 * This file contains custom functions for the theme
 * 
 * @package		Panache WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
?>
<?php
//temporary load to check translation
//load_textdomain( 'panache', get_template_directory() . '/languages/fr_FR.mo' );
/**
 * This file set up as per 
 * @link http://wp.tutsplus.com/tutorials/reusable-custom-meta-boxes-part-1-intro-and-basic-fields/
 * The intent is to set up a generalized set of functions to add options to page set ups, allowing 
 * for custom page options.
 * 
 */
/**
 * =============================================================================================
 *                     Custom Page Meta Box
 * =============================================================================================
 */ 
 /** 
  * Add the Meta Box
  * 
  * source: @link http://codex.wordpress.org/Function_Reference/add_meta_box
  * add_meta_box( $id, $title, $callback, $post_type, $context, $priority, $callback_args );
  * $id : (string) (required) HTML 'id' attribute of the edit screen section Default: None 
  * $title : (string) (required) Title of the edit screen section, visible to user Default: None 
  * $callback : (callback) (required) Function that prints out the HTML for the edit screen section. 
  *             Pass function name as a string
  * $post_type : (string) (required) The type of Write screen on which to show the edit screen section 
  *              ('post', 'page', 'link', or 'custom_post_type' where custom_post_type is the custom post type slug)
  *              Default: None 
  * $context : (string) (optional) The part of the page where the edit screen section should be shown 
  *            ('normal', 'advanced', or 'side'). (Note that 'side' doesn't exist before 2.7)Default: 'advanced' 
  * $priority : (string) (optional) The priority within the context where the boxes should show 
  *             ('high', 'core', 'default' or 'low') Default: 'default' 
  * $callback_args : (array) (optional) Arguments to pass into your callback function. The callback will receive 
  *                  the $post object and whatever parameters are passed through this variable. Default: null 
  * 
  */
if ( !function_exists ('panache_add_page_custom_meta_box') ) {
	function panache_add_page_custom_meta_box() {
		add_meta_box(
			'panache_page_custom_meta_box', // $id  
			'Panache Page Options', // $title  
			'panache_show_page_custom_meta_box', // $callback  
			'page', // $page  
			'normal', // $context  
			'high'); // $priority  
	}
	add_action('add_meta_boxes', 'panache_add_page_custom_meta_box');   
}

/**
 * Array of elements
 * 
 * This section defines the array of elements that will be used to 
 * set up the custom page options
 * 
 */
$panache_page_custom_meta_fields = array(
	array(
		'label'=> __( 'Page Layout Options' , 'panache' ),
		'desc'  => __( 'Which layout do you want to use?' , 'panache' ),
		'id'    => 'panache_metabox_page_layout',
		'type'  => 'select',
		'options' => array (
			'C_A'		=>	__( 'Content - Sidebar A', 'panache' ),
			'A_C'		=>	__( 'Sidebar A - Content', 'panache' ),
			'A_C_B'		=>	__( 'Sidebar A - Content - Sidebar B', 'panache' ),
			'A_B_C'		=>	__( 'Sidebar A - Sidebar B - Content', 'panache' ),
			'C_A_B'		=>	__( 'Content - Sidebar A - Sidebar B', 'panache' ),
			'M_C_B'		=>	__( 'Menu Sidebar A - Content - Sidebar B', 'panache' ),
			'M_B_C'		=>	__( 'Menu Sidebar A - Sidebar B - Content', 'panache' ),
			'M_C'		=>	__( 'Menu Sidebar A - Content', 'panache' ),
			'F_W'		=>	__( 'Full Width' , 'panache' )
		),
		'default' =>'C_A'
	),
	array(
		'label'=> __('Page Title Option','panache'),
		'desc'  => __('Select a title layout or no title','panache'),
		'id'    => 'panache_metabox_title',
		'type'  => 'select',
		'options' => array (
			'left title'	=>__( 'left title', 'panache' ),
			'right title'	=>__( 'right title', 'panache' ),
			'center title'	=>__( 'center title', 'panache' ),
			'no title'		=>__( 'no title', 'panache' ),
		),
		'default' =>'left title'
		),
	array(  
		'label'=> __( 'Sidebar A Name' , 'panache'),
		'desc'  => __( 'Which sidebar do you want to use?' , 'panache' ),
		'id'    => 'panache_metabox_sidebar_a',
		'type'  => 'select',
		'options' => array (
			'default_a'		=>	__( 'Default Sidebar A' , 'panache' ),
			'default_b'		=>	__( 'Default Sidebar B' , 'panache' ),
			'blog_a'		=>	__( 'Blog Sidebar A' , 'panache' ),
			'blog_b'		=>	__( 'Blog Sidebar B' , 'panache' ),
			'error_404_a'	=>	__( 'Error Page Sidebar A' , 'panache' ),
			'error_404_b'	=>	__( 'Error Page Sidebar B' , 'panache' ),
			'about_a'		=>	__( 'About Page Sidebar A' , 'panache' ),
			'about_b'		=>	__( 'About Page Sidebar B' , 'panache' ),
			'contact_a'		=>	__( 'Contact Page Sidebar A' , 'panache' ),
			'contact_b'		=>	__( 'Contact Page Sidebar B' , 'panache' ),
			'sidebar_1'		=>	__( 'Extra Sidebar 1' , 'panache' ),
			'sidebar_2'		=>	__( 'Extra Sidebar 2' , 'panache' ),
			'sidebar_3'		=>	__( 'Extra Sidebar 3' , 'panache' ),
			'sidebar_4'		=>	__( 'Extra Sidebar 4' , 'panache' ),
			'sidebar_5'		=>	__( 'Extra Sidebar 5' , 'panache' ),
			'sidebar_6'		=>	__( 'Extra Sidebar 6' , 'panache' )
		),
		'default' =>'default_a'
	),	
	array(  
		'label'=> __('Sidebar B Name','panache'),
		'desc'  => __('Which sidebar do you want to use?','panache'),
		'id'    => 'panache_metabox_sidebar_b',
		'type'  => 'select',
		'options' => array (
			'default_b'		=>	__( 'Default Sidebar B' , 'panache' ),
			'default_a'		=>	__( 'Default Sidebar A' , 'panache' ),
			'blog_a'		=>	__( 'Blog Sidebar A' , 'panache' ),
			'blog_b'		=>	__( 'Blog Sidebar B' , 'panache' ),
			'error_404_a'	=>	__( 'Error Page Sidebar A' , 'panache' ),
			'error_404_b'	=>	__( 'Error Page Sidebar B' , 'panache' ),
			'about_a'		=>	__( 'About Page Sidebar A' , 'panache' ),
			'about_b'		=>	__( 'About Page Sidebar B' , 'panache' ),
			'contact_a'		=>	__( 'Contact Page Sidebar A' , 'panache' ),
			'contact_b'		=>	__( 'Contact Page Sidebar B' , 'panache' ),
			'sidebar_1'		=>	__( 'Extra Sidebar 1' , 'panache' ),
			'sidebar_2'		=>	__( 'Extra Sidebar 2' , 'panache' ),
			'sidebar_3'		=>	__( 'Extra Sidebar 3' , 'panache' ),
			'sidebar_4'		=>	__( 'Extra Sidebar 4' , 'panache' ),
			'sidebar_5'		=>	__( 'Extra Sidebar 5' , 'panache' ),
			'sidebar_6'		=>	__( 'Extra Sidebar 6' , 'panache' )
		),
		'default' =>'default_b'
	),
/* Feature */
	array(
		'label' => __('Feature Slider Category','panache'),
		'desc' => __('Only for pages using a feature slider','panache'),
		'id'    => 'panache_metabox_feature_category',
		'type'  => 'tax_select'
	),
	array(  
		'label'=> __('Feature Slider Type','panache'),
		'desc'  => __('Pick the type of feature you want','panache'),
		'id'    => 'panache_metabox_feature_type',
		'type'  => 'select',
		'options' => array (
			'No feature'							=>	__( 'No feature', 'panache' ),
			'Small slides button navigation'		=>	__( 'Small slides button navigation' , 'panache' ),
			'Small slides thumbnail navigation'		=>	__( 'Small slides thumbnail navigation' , 'panache' ),
			'Small slides no navigation'			=>	__( 'Small slides no navigation' , 'panache' ),
			'Full slides button navigation'			=>	__( 'Full slides button navigation' , 'panache' ),
			'Full slides thumbnail navigation'		=>	__( 'Full slides thumbnail navigation' , 'panache' ),
			'Full slides no navigation'				=>	__( 'Full slides no navigation' , 'panache' ),
			'Center slides button navigation'		=>	__( 'Center slides button navigation' , 'panache' ),
			'Center slides thumbnail navigation'	=>	__( 'Center slides thumbnail navigation' , 'panache' ),
			'Center slides no navigation'			=>	__( 'Center slides no navigation' , 'panache' ),
			'Full slides carousel navigation'		=>	__( 'Full slides carousel navigation' , 'panache' )
		),
		'default' => __('No feature','panache')
	),
	array(  
		'label'=> __('Feature Slider Sidebar','panache'),
		'desc'  => __('Widgetized area for applicable Feature Page Sliders','panache'),
		'id'    => 'panache_metabox_feature_widget',
		'type'  => 'select',
		'options' => array (
			'feature_a'		=>	__( 'Feature Sidebar A' , 'panache' ),
			'feature_b'		=>	__( 'Feature Sidebar B' , 'panache' ),
			'feature_c'		=>	__( 'Feature Sidebar C' , 'panache' ),
			'feature_d'		=>	__( 'Feature Sidebar D' , 'panache' ),
			'sidebar_1'		=>	__( 'Extra Sidebar 1' , 'panache' ),
			'sidebar_2'		=>	__( 'Extra Sidebar 2' , 'panache' ),
			'sidebar_3'		=>	__( 'Extra Sidebar 3' , 'panache' ),
			'sidebar_4'		=>	__( 'Extra Sidebar 4' , 'panache' ),
			'sidebar_5'		=>	__( 'Extra Sidebar 5' , 'panache' ),
			'sidebar_6'		=>	__( 'Extra Sidebar 6' , 'panache' )
		),
		'default' =>'feature_a'
	),
/* Portfolio */	
	array(
		'label' => __('Portfolio Feature Category','panache'),
		'desc' => __('Only for Portfolio Pages','panache'),
		'id'    => 'panache_portfolio_category',
		'type'  => 'tax_select'
	),
	array(  
		'label'=> __('Portfolio Columns','panache'),
		'desc'  => __('Only for Portfolio Pages','panache'),
		'id'    => 'panache_portfolio_columns',
 		'type'  => 'select',
		'options' => array (
			'1 column'		=>	__( '1 column' , 'panache' ),
			'2 columns'		=>	__( '2 columns' , 'panache' ),
			'3 columns'		=>	__( '3 columns' , 'panache' ),
			'4 columns'		=>	__( '4 columns' , 'panache' ),
			'fullwidth'		=>	__( 'Full Width' , 'panache' )
		),
		'default' => '1 column'
	),
	array(  
		'label'=> __('Include Portfolio Post Content Title','panache'),
		'desc'  => __('Click to include the post content title','panache'),
		'id'    => 'panache_metabox_include_post_content_title',
		'type'  => 'checkbox',
		'default' => 0
 	),
	array(  
		'label'=> __('Include Portfolio Post Content','panache'),
		'desc'  => __('Not used for 1 column portfolio pages','panache'),
		'id'    => 'panache_metabox_include_post_content',
		'type'  => 'checkbox',
		'default' => 0
 	),
	array(  
		'label'=> __('Include Portfolio Image Caption','panache'),
		'desc'  => __('Only used for all Portfolio Pages','panache'),
		'id'    => 'panache_metabox_include_image_caption',
		'type'  => 'checkbox',
		'default' => 0
	),
	array(  
		'label'=> __('Include Portfolio Image Description','panache'),
		'desc'  => __('Only used for all Portfolio Pages','panache'),
		'id'    => 'panache_metabox_include_image_description',
		'type'  => 'checkbox',
		'default' => 0
	),	
);

/**
 * The Callback
 * 
 * The callback is used to display the options on the page
 * 
 */
if ( !function_exists ('panache_show_page_custom_meta_box') ) {
	function panache_show_page_custom_meta_box() {
		global $panache_page_custom_meta_fields, $post;
		// Use nonce for verification  
		echo '<input type="hidden" name="panache_page_meta_box_nonce" value="'.wp_create_nonce(basename(__FILE__)).'" />';  
		// Begin the field table and loop  
		echo '<table class="form-table">';
		foreach ($panache_page_custom_meta_fields as $field) {
			// get value of this field if it exists for this post  
			$meta = get_post_meta($post->ID, $field['id'], true);

			// begin a table row with  
			echo '<tr> 
					<th><label for="'.$field['id'].'">'.$field['label'].'</label></th> 
					<td>';  
						switch($field['type']) {
							// text  
							case 'text':
								echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$meta.'" size="30" /> 
										&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;
							// textarea  
							case 'textarea':
								echo '<textarea name="'.$field['id'].'" id="'.$field['id'].'" cols="60" rows="4">'.$meta.'</textarea> 
										&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;	
							// checkbox  
							case 'checkbox':
								echo '<input type="checkbox" name="'.$field['id'].'" id="'.$field['id'].'" ',$meta ? ' checked="checked"' : '','/> 
										&nbsp;<label for="'.$field['id'].'">'.$field['desc'].'</label>';
							break;
							// select  
							case 'select':
								$valid_options = array();
								$valid_options = $field['options'];
								
								echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
								foreach ($field['options'] as $key => $option) {
									echo '<option'.selected( $key == $meta ).' value="'.$option.'">'.$option.'</option>';  
								}
								echo '</select>&nbsp;<span class="description">'.$field['desc'].'</span>';  
							break;
							// tax_select  
							case 'tax_select':
								$categories = get_categories();
							
								echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
								foreach ($categories as $category) {
									echo '<option', $meta == $category->name? ' selected="selected"' : '', ' value="'.$category->name.'">'.$category->name.'</option>'; 
								}
								echo '</select>&nbsp;<span class="description">'.$field['desc'].'</span>';
							break;
						}//end switch  
			echo '</td></tr>';
		}// end foreach  
		echo '</table>';// end table
	}
}

/**
 * Save the data
 * 
 * This functon takes the meta data and saves it to the WordPress Database
 */
if ( !function_exists ('panache_save_page_custom_meta') ) {
	function panache_save_page_custom_meta($post_id) {
		global $panache_page_custom_meta_fields;
		
		// verify nonce  
		if (isset($_POST['panache_page_meta_box_nonce']) == false || 
			check_admin_referer( basename(__FILE__) , 'panache_page_meta_box_nonce' ) == false )
			return $post_id;
		// check autosave  
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;
		// check permissions  
		if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
			if (!current_user_can('edit_page', $post_id))
				return $post_id;
		} elseif (!current_user_can('edit_post', $post_id)) {
			return $post_id;
		}
		// loop through fields and save the data  
		foreach ($panache_page_custom_meta_fields as $field) {
			$old = get_post_meta($post_id, $field['id'], true);
			if ($field['type'] == 'select' )   {
				if(isset($_POST[$field['id']])) {
					$values = array();	
					$values = $field['options'];
					//wp_die(var_dump($values));
					foreach ( $values as $key => $value) {
						if($value == $_POST[$field['id']] ){$new = $key;}
					}
					//wp_die($new);
					//$new = $_POST[$field['id']];
					$new = sanitize_text_field($new);
				} else {
					$new = $field['default'];
				}
			} elseif ($field['type'] == 'tax_select' ) {
				if(isset($_POST[$field['id']])) {
					$new = $_POST[$field['id']];
					$new = sanitize_text_field($new);
				}
			} elseif ($field['type'] == 'checkbox' ) {
				$new = ( ( isset($_POST[$field['id']]) && true == $_POST[$field['id']] ) ? true : $field['default'] );
			}
			if ($new && $new != $old) {
				update_post_meta($post_id, $field['id'], $new);
			} elseif ('' == $new && $old) {
				delete_post_meta($post_id, $field['id'], $old);
			}
		} // end foreach  
	}
	add_action('save_post', 'panache_save_page_custom_meta');
}

/**
 * =============================================================================================
 *                     Custom Post Meta Box
 * =============================================================================================
 */
 if ( !function_exists ('panache_add_post_custom_meta_box') ) {
	function panache_add_post_custom_meta_box() {
		add_meta_box(  
			'panache_post_custom_meta_box', // $id  
			'Panache Post Options', // $title  
			'panache_show_post_custom_meta_box', // $callback  
			'post', // $post  
			'normal', // $context  
			'high'); // $priority  
	}
	add_action('add_meta_boxes', 'panache_add_post_custom_meta_box');   
}

/**
 * Array of elements
 */
$panache_post_custom_meta_fields = array(
	array(  
		'label'=> __('Do not display this post','panache'),
		'desc'  => __('Click to exclude in blog, or other pages','panache'),
		'id'    => 'panache_metabox_exclude_post',
		'type'  => 'checkbox',
		'default' => 0
	),
	array(  
		'label'=> __('Link image to this post','panache'),
		'desc'  => __('Make sure to add some content','panache'),
		'id'    => 'panache_metabox_link_to_post',
		'type'  => 'checkbox',
		'default' => 0
	),
	array(  
		'label'=> __('Link to Feature Image File','panache'),
		'desc'  => __('Great option if you are using color box','panache'),
		'id'    => 'panache_metabox_link_to_image',
		'type'  => 'checkbox',
		'default' => 0
	),
	array(  
		'label'=> __('Feature Image Custom Link','panache'),
		'desc'  => __('Add custom link','panache'),
		'id'    => 'panache_custom_feature_link',
		'type'  => 'url',
		'default' => ''
	),
	array(  
	'label'=> __('Use Post Title instead of Image Caption','panache'),
	'desc'  => __('For Nivo Feature Slider - post title appears at image bottom','panache'),
	'id'    => 'panache_metabox_include_feature_title',
	'type'  => 'checkbox',
	'default' => 0
	),
);

// The Callback
if ( !function_exists ('panache_show_post_custom_meta_box') ) {
	function panache_show_post_custom_meta_box() {
		global $panache_post_custom_meta_fields, $post;
		// Use nonce for verification  
		echo '<input type="hidden" name="panache_post_meta_box_nonce" value="'.wp_create_nonce(basename(__FILE__)).'" />';
		// Begin the field table and loop  
		echo '<table class="form-table">';
		foreach ($panache_post_custom_meta_fields as $field) {
			// get value of this field if it exists for this post  
			$meta = get_post_meta($post->ID, $field['id'], true);
			// begin a table row with  
			echo '<tr>
				<th><label for="'.$field['id'].'">'.$field['label'].'</label></th>
				<td>';
				switch($field['type']) {
					// text  
					case 'text':
						echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.sanitize_text($meta).'" size="30" />
								<br /><span class="description">'.$field['desc'].'</span>';
					break;
					//url
					case 'url':
						echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.esc_url($meta).'" size="30" />
								<br /><span class="description">'.$field['desc'].'</span>';
					break;
					// textarea  
					case 'textarea':
						echo '<textarea name="'.$field['id'].'" id="'.$field['id'].'" cols="60" rows="4">'.$meta.'</textarea>
								<br /><span class="description">'.$field['desc'].'</span>';
					break;
					// checkbox  
					case 'checkbox':
						echo '<input type="checkbox" name="'.$field['id'].'" id="'.$field['id'].'" ',$meta ? ' checked="checked"' : '','/>
								<label for="'.$field['id'].'">'.$field['desc'].'</label>';
					break;
					// select  
					case 'select':
						$valid_options = array();
						$valid_options = $field['options'];
						echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
						foreach ($field['options'] as $option) {
							//echo '<option', $meta == $option['value'] ? ' selected="selected"' : '', ' value="'.$option['value'].'">'.$option['label'].'</option>'; 
							echo '<option', $meta == $option? ' selected="selected"' : '', ' value="'.$option.'">'.$option.'</option>'; 
						}
						echo '</select><br /><span class="description">'.$field['desc'].'</span>';
					break;
						// tax_select  
					case 'tax_select':
						$categories = get_categories();
						$valid_options = array();
						$valid_options = $field['options'];
						echo '<select name="'.$field['id'].'" id="'.$field['id'].'">';
						foreach ($categories as $category) {
							//echo '<option', $meta == $option['value'] ? ' selected="selected"' : '', ' value="'.$option['value'].'">'.$option['label'].'</option>'; 
							echo '<option', $meta == $category->name? ' selected="selected"' : '', ' value="'.$category->name.'">'.$category->name.'</option>'; 
						}
						echo '</select><br /><span class="description">'.$field['desc'].'</span>';
					break;
				}//end switch  
			echo '</td></tr>';  
		} // end foreach  
		echo '</table>'; // end table  
	}
}
 
// Save the Data
if ( !function_exists ('panache_save_post_custom_meta') ) {
	function panache_save_post_custom_meta($post_id) {
		global $panache_post_custom_meta_fields;
		
		// verify nonce  
		if (isset($_POST['panache_post_meta_box_nonce']) == false || 
			check_admin_referer( basename(__FILE__) , 'panache_post_meta_box_nonce' ) == false )
			return $post_id;
		// check autosave  
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;
		// check permissions  
		if (isset($_POST['post_type']) && 'post' == $_POST['post_type']) {
			if (!current_user_can('edit_post', $post_id))
				return $post_id;
		} elseif (!current_user_can('edit_post', $post_id)) {
			return $post_id;  
		}
		// loop through fields and save the data  
		foreach ($panache_post_custom_meta_fields as $field) {  
			$old = get_post_meta($post_id, $field['id'], true);
			if ($field['type'] == 'text' )   {
				if(isset($_POST[$field['id']])) {
					$new = $_POST[$field['id']];
					$new = sanitize_text_field($new);
				} else {
					$new = $field['default'];
				}
			} elseif ($field['type'] == 'url' ) {
				if(isset($_POST[$field['id']])) {
					$new = $_POST[$field['id']];
					$new = esc_url($new);
				} else {
					$new = $field['default'];
				}
			} elseif ($field['type'] == 'checkbox' ) {
				$new = ( ( isset($_POST[$field['id']]) && true == $_POST[$field['id']] ) ? true : $field['default'] );
			}
			if ($new && $new != $old) {  
				update_post_meta($post_id, $field['id'], $new);
			} elseif ('' == $new && $old) {  
				delete_post_meta($post_id, $field['id'], $old);
			}
		} // end foreach  
	}
	add_action('save_post', 'panache_save_post_custom_meta');
}

?>