<?php
/**
 * Posts functions file
 * 
 * This file contains functions for posts including meta 
 * 
 * @package		Panache WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
?>
<?php

/**
 * This function checks the post format type and calls the appropriate template
 * @link http://codex.wordpress.org/Post_Formats
 */
if( !function_exists( 'panache_post_format' ) ) {
	 function panache_post_format(){

		if ( has_post_format( 'aside' ) ) {
			get_template_part('/template-parts/postformat-parts/postformat','aside');
		} elseif ( has_post_format( 'audio' )) {
			get_template_part('/template-parts/postformat-parts/postformat','audio');
		} elseif ( has_post_format( 'chat' )) {
			get_template_part('/template-parts/postformat-parts/postformat','chat');
		} elseif ( has_post_format( 'gallery' )) {
			get_template_part('/template-parts/postformat-parts/postformat','gallery');
		} elseif ( has_post_format( 'image' )) {
			get_template_part('/template-parts/postformat-parts/postformat','image');
		} elseif ( has_post_format( 'link' )) {
			get_template_part('/template-parts/postformat-parts/postformat','link');
		} elseif ( has_post_format( 'quote' )) {
			get_template_part('/template-parts/postformat-parts/postformat','quote');
		} elseif ( has_post_format( 'status' )) {
			get_template_part('/template-parts/postformat-parts/postformat','status');
		} elseif ( has_post_format( 'video' )) {
			get_template_part('/template-parts/postformat-parts/postformat','video');
		} else {
			get_template_part('/template-parts/postformat-parts/postformat','standard');
		}

	}
}

/**
 * This function checks the post format type and calls the appropriate template for the grid posts
 * @link http://codex.wordpress.org/Post_Formats
 */
if( !function_exists( 'panache_grid_post_format' ) ) {
	 function panache_grid_post_format(){

		if ( has_post_format( 'aside' ) ) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_aside');
		} elseif ( has_post_format( 'audio' )) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_audio');
		} elseif ( has_post_format( 'chat' )) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_chat');
		} elseif ( has_post_format( 'gallery' )) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_gallery');
		} elseif ( has_post_format( 'image' )) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_image');
		} elseif ( has_post_format( 'link' )) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_link');
		} elseif ( has_post_format( 'quote' )) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_quote');
		} elseif ( has_post_format( 'status' )) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_status');
		} elseif ( has_post_format( 'video' )) {
			get_template_part('/template-parts/postformat-parts/postformat','grid_video');
		} else {
			get_template_part('/template-parts/postformat-parts/postformat','grid_standard');
		}

	}
}

/* ======================================================================================
 * Chat Functions
 * ====================================================================================== */

/**
 * This function filters the post content when viewing a post with the "chat" post format.  It formats the 
 * content with structured HTML markup to make it easy for theme developers to style chat posts.  The 
 * advantage of this solution is that it allows for more than two speakers (like most solutions).  You can 
 * have 100s of speakers in your chat post, each with their own, unique classes for styling.
 *
 * @author David Chandra
 * @link http://www.turtlepod.org
 * @author Justin Tadlock
 * @link http://justintadlock.com
 * @copyright Copyright (c) 2012
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * @link http://justintadlock.com/archives/2012/08/21/post-formats-chat
 *
 * @global array $panache_post_format_chat_ids An array of IDs for the chat rows based on the author.
 * @param string $content The content of the post.
 * @return string $chat_output The formatted content of the post.
 */
if( !function_exists( 'panache_chat_content' ) ) {
	function panache_chat_content( $content ) {
		global $panache_post_format_chat_ids;
		
		/* ka added this because of filter error on password protecting post */
		if( post_password_required() )
			return $content;
		
		/* If this is not a 'chat' post, return the content. */
		if ( !has_post_format( 'chat' ) )
			return $content;
	
		/* Set the global variable of speaker IDs to a new, empty array for this chat. */
		$panache_post_format_chat_ids = array();
	
		/* Allow the separator (separator for speaker/text) to be filtered. */
		$separator = apply_filters( 'panache_format_chat_separator', ':' );
	
		/* Open the chat transcript div and give it a unique ID based on the post ID. */
		$chat_output = "\n\t\t\t" . '<div id="chat-transcript-' . esc_attr( get_the_ID() ) . '" class="chat-transcript">';
	
		/* Split the content to get individual chat rows. */
		$chat_rows = preg_split( "/(\r?\n)+|(<br\s*\/?>\s*)+/", $content );
	
		/* Loop through each row and format the output. */
		foreach ( $chat_rows as $chat_row ) {
	
			/* If a speaker is found, create a new chat row with speaker and text. */
			if ( strpos( $chat_row, $separator ) ) {
	
				/* Split the chat row into author/text. */
				$chat_row_split = explode( $separator, trim( $chat_row ), 2 );
	
				/* Get the chat author and strip tags. */
				$chat_author = strip_tags( trim( $chat_row_split[0] ) );
	
				/* Get the chat text. */
				$chat_text = trim( $chat_row_split[1] );
	
				/* Get the chat row ID (based on chat author) to give a specific class to each row for styling. */
				$speaker_id = panache_chat_row_id( $chat_author );
	
				/* Open the chat row. */
				$chat_output .= "\n\t\t\t\t" . '<div class="chat-row ' . sanitize_html_class( "chat-speaker-{$speaker_id}" ) . '">';
	
				/* Add the chat row author. */
				$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-author ' . sanitize_html_class( strtolower( "chat-author-{$chat_author}" ) ) . ' vcard"><cite class="fn">' . apply_filters( 'my_post_format_chat_author', $chat_author, $speaker_id ) . '</cite>' . $separator . '</div>';
	
				/* Add the chat row text. */
				$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-text">' . str_replace( array( "\r", "\n", "\t" ), '', apply_filters( 'my_post_format_chat_text', $chat_text, $chat_author, $speaker_id ) ) . '</div>';
	
				/* Close the chat row. */
				$chat_output .= "\n\t\t\t\t" . '</div><!-- .chat-row -->';
			}
	
			/**
			 * If no author is found, assume this is a separate paragraph of text that belongs to the
			 * previous speaker and label it as such, but let's still create a new row.
			 */
			else {
	
				/* Make sure we have text. */
				if ( !empty( $chat_row ) ) {
	
					/* Open the chat row. */
					$chat_output .= "\n\t\t\t\t" . '<div class="chat-row ' . sanitize_html_class( "chat-speaker-{$speaker_id}" ) . '">';
	
					/* Don't add a chat row author.  The label for the previous row should suffice. */
	
					/* Add the chat row text. */
					$chat_output .= "\n\t\t\t\t\t" . '<div class="chat-text">' . str_replace( array( "\r", "\n", "\t" ), '', apply_filters( 'my_post_format_chat_text', $chat_row, $chat_author, $speaker_id ) ) . '</div>';
	
					/* Close the chat row. */
					$chat_output .= "\n\t\t\t</div><!-- .chat-row -->";
				}
			}
		}
	
		/* Close the chat transcript div. */
		$chat_output .= "\n\t\t\t</div><!-- .chat-transcript -->\n";
	
		/* Return the chat content and apply filters for developers. */
		return apply_filters( 'panache_format_chat_content', $chat_output );
	}

	/* Filter the content of chat posts. */
	add_filter( 'the_content', 'panache_chat_content' );
	
	/* Auto-add paragraphs to the chat text. */
	add_filter( 'panache_format_chat_text', 'wpautop' );
	
}

/**
 * This function returns an ID based on the provided chat author name.  It keeps these IDs in a global 
 * array and makes sure we have a unique set of IDs.  The purpose of this function is to provide an "ID"
 * that will be used in an HTML class for individual chat rows so they can be styled.  So, speaker "John" 
 * will always have the same class each time he speaks.  And, speaker "Mary" will have a different class 
 * from "John" but will have the same class each time she speaks.
 *
 * @author David Chandra
 * @link http://www.turtlepod.org
 * @author Justin Tadlock
 * @link http://justintadlock.com
 * @copyright Copyright (c) 2012
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * @link http://justintadlock.com/archives/2012/08/21/post-formats-chat
 *
 * @global array $panache_post_format_chat_ids An array of IDs for the chat rows based on the author.
 * @param string $chat_author Author of the current chat row.
 * @return int The ID for the chat row based on the author.
 */
if( !function_exists( 'panache_chat_row_id' ) ) {
	function panache_chat_row_id( $chat_author ) {
		global $panache_post_format_chat_ids;
	
		/* Let's sanitize the chat author to avoid craziness and differences like "John" and "john". */
		$chat_author = strtolower( strip_tags( $chat_author ) );
	
		/* Add the chat author to the array. */
		$panache_post_format_chat_ids[] = $chat_author;
	
		/* Make sure the array only holds unique values. */
		$panache_post_format_chat_ids = array_unique( $panache_post_format_chat_ids );
	
		/* Return the array key for the chat author and add "1" to avoid an ID of "0". */
		return absint( array_search( $chat_author, $panache_post_format_chat_ids ) ) + 1;
	}
}

/**
 * Retrieves the IDs for images in a gallery.
 *
 * @uses get_post_galleries() first, if available. Falls back to shortcode parsing,
 * then as last option uses a get_posts() call.
 *
 * @since Twenty Eleven 1.6.
 *
 * @return array List of image IDs from the post gallery.
 */
if( !function_exists( 'panache_get_gallery_images' ) ) {
	 function panache_get_gallery_images() {
	
		$images = array();
		$pattern = get_shortcode_regex();
		preg_match( "/$pattern/s", get_the_content(), $match );
		$atts = shortcode_parse_atts( $match[3] );
		
		if ( isset( $atts['ids'] ) )
			$images = explode( ',', $atts['ids'] );
		
		if ( !$images ) {
			$images = get_posts( array(
				'fields'         => 'ids',
				'numberposts'    => 999,
				'order'          => 'ASC',
				'orderby'        => 'menu_order',
				'post_mime_type' => 'image',
				'post_parent'    => get_the_ID(),
				'post_type'      => 'attachment',
			) );
		}

		return $images;
	 }
}

/**
 * This function is called by the post format functions and supplies the meta 
 * for the top section of the post.
 */
if ( !function_exists ( 'panache_post_metatop' ) ) {
	function panache_post_metatop() {
		
		$include_timestamp = intval( panache_get_option( 'panache_timestamp_in_blog' ) );
		$include_author = intval( panache_get_option('panache_author_in_blog' ) );
		$include_category = intval( panache_get_option('panache_category_in_blog' ) );
		$use_post_meta_icons = intval( panache_get_option('panache_use_post_meta_icons' ) );

		//return if no meta
		if( false == $include_timestamp && false == $include_author && false == $include_category ) {
			?><div class="clearfix"></div><?php
			return;
		} 
		
		?>
		
		<div class="postmetatop">
			
			<?php if( true == $include_timestamp  ) {
			
				if( true == $use_post_meta_icons ) { ?>
					<span class="timestamp post-date updated"><i class="fa fa-clock-o" title="Timestamp"></i>&nbsp;<?php the_time(get_option('date_format')); ?></span>
				<?php } else { ?>
					<span class="timestamp post-date updated"><?php the_time(get_option('date_format')); ?></span>
				<?php }
			
			} else { ?>
				<span class="screen-reader-text updated"><?php the_time(get_option('date_format')); ?></span>
			<?php }
		
			if( true == $include_author ) {
				
				if( true == $use_post_meta_icons ) { ?> 
					<span class="vcard author post-author"><span class="author fn"><i class="fa fa-user" title="Author"></i>&nbsp;<?php the_author_posts_link(); ?></span></span>
				<?php } else { ?> 
					<span class="vcard author post-author"><span class="author fn"><?php _e('By:','panache'); ?>&nbsp;<?php the_author_posts_link(); ?></span></span>
				<?php }
					
			} else { ?>
				<span class="screen-reader-text vcard author post-author"><span class="author fn"><?php _e('By:','panache'); ?>&nbsp;<?php the_author_posts_link(); ?></span></span>
			<?php }

		
			if( true == $include_category ) {
				
				if( true == $use_post_meta_icons ) {
					if( has_category() == true ) { ?>
						<span class="categories"><i class="fa fa-bookmark" title="Categories"></i>&nbsp;<?php the_category(', '); ?></span>
					<?php }	
				} else {
					if( has_category() == true ) { ?>
						<span class="categories"><?php _e('In:','panache'); ?>&nbsp;<?php the_category(', '); ?></span>
					<?php }
				}
				
			}
					
		?>
		</div>
		<div class="clearfix"></div>
		<?php
	}
}

/**
 * This function is called by all the post formats to add the meta bottom strip
 */
if ( !function_exists ( 'panache_post_metabottom' ) ) {
	function panache_post_metabottom( $panache_post_format ) {
		
		$include_tags = intval( panache_get_option( 'panache_tags_in_blog' ) );
		$use_post_meta_icons = intval( panache_get_option( 'panache_use_post_meta_icons' ) );
		
		$link_pages_exist = (wp_link_pages('echo=0') != '' )? true:false;
		$title_exists = ( get_the_title() != '' )? true:false;
		$user_exists = (is_user_logged_in() && current_user_can( 'edit_posts') )? true:false;
		if( $include_tags == 1 && get_the_tags() != '' ){$tags_exist = true;}else{$tags_exist = false;}
		
		if( $link_pages_exist == 1 || $tags_exist == 1 || $title_exists != 1 || $user_exists == 1 ) {
		
			echo '<div class="postmetabottom">';
			
				if( $panache_post_format == 'status' || $panache_post_format == 'aside' ) {
					
					edit_post_link(__('Edit','panache'),'<span class="edit"><i class="fa fa-edit" title="Edit"></i>&nbsp;','</span>');
					
				} else { 
					
					if( true == $use_post_meta_icons) { ?>
						<span class="pagelist"><?php $page_text = '<i class="fa fa-copy" title="Pages"></i>&nbsp;'; wp_link_pages('before='.$page_text.':&after='); ?></span>
					<?php } else { ?>
						<span class="pagelist"><?php $page_text = __('Pages','panache'); wp_link_pages('before='.$page_text.':&after='); ?></span>
					<?php }
					
					if( true == $include_tags ) {
						if( true == $use_post_meta_icons) {
							if( has_tag() == true ) { ?><span class="taglist"><i class="fa fa-tags" title="Tags"></i>&nbsp;<?php the_tags("") ?></span> <?php }
						} else {
							if( has_tag() == true ) { ?><span class="taglist"><?php the_tags(__('Tags: ','panache')); ?></span><?php }
						}
					}
					
					if( get_the_title() == "" ) {
						if( true == $use_post_meta_icons) {
							echo '<span class="no-title"><a href="'.get_permalink().'" rel="bookmark" title="Untitled Link" ><i class="fa fa-warning">&nbsp;</i>'.__("Single Page Link","panache").'</a></span>';
						} else {
							echo '<span class="no-title"><a href="'.get_permalink().'" rel="bookmark" title="Untitled Link" >'.__("Single Page Link","panache").'</a></span>';
						}
					}
				
					if( true == $use_post_meta_icons) {
						edit_post_link(__('Edit','panache'),'<span class="edit"><i class="fa fa-edit" title="Edit"></i>&nbsp;','</span>');
					} else { ?>
						<span class="edit"><?php edit_post_link(__('Edit','panache')); ?></span>
					<?php }
				
				}
			echo '</div>';
			
		}
	}
}

/**
 * This function is called by all the post formats to add the comments count and link
 */
if ( !function_exists ( 'panache_comments_link' ) ) {
	function panache_comments_link() {
		
		global $post;
		$use_post_meta_icons = intval( panache_get_option( 'panache_use_post_meta_icons' ) );
		$post_comments = get_comments( array ( 'type' => 'comment', 'post_id' => $post->ID ));
		
		if( true == $use_post_meta_icons ) { ?>
			<span class="post-title-comments"><i class="fa fa-comment" title="Comments"></i>&nbsp;<a href="<?php comments_link(); ?>"><?php echo count($post_comments); ?></a></span>
		<?php } else { ?>
			<span class="post-title-comments"><a class="post-comments-button" href="<?php comments_link(); ?>"><?php echo count($post_comments); ?></a></span>
		<?php }

	}
}

/**
 *  Excerpt Filters WordPress Codex
 */
/**
 * Change the excerpt filtering to allow html
 * @link http://wordpress.stackexchange.com/questions/141125/allow-html-in-excerpt/141136#141136
 */
if ( !function_exists( 'panache_allowed_excerpt_tags' ) ) { 
	function panache_allowed_excerpt_tags() {
		// Add custom tags to this string
		return '<script>,<style>,<br>,<div>,<em>,<i>,<ul>,<ol>,<li>,<a>,
		<p>,<img>,<span>,<video>,<audio>,<source>,<blockquote>,<cite>
		<h1><h2><h3><h4><h5><h6>'; 
	}
}
 
/**
 * @Author: Boutros AbiChedid
 * @Date:   June 20, 2011
 * @Websites: http://bacsoftwareconsulting.com/ ; http://blueoliveonline.com/
 * @Description: Preserves HTML formating to the automatically generated Excerpt.
 * Also Code modifies the default excerpt_length and excerpt_more filters.
 * @Tested: Up to WordPress version 3.1.3
 * http://bacsoftwareconsulting.com/blog/index.php/wordpress-cat/how-to-preserve-html-tags-in-wordpress-excerpt-without-a-plugin/
 * Modified by 
 * @Author: Kevin Archibald
 */
if ( !function_exists( 'panache_trim_excerpt' ) ) { 
	function panache_trim_excerpt($panache_excerpt) {
		
		global $post;
		//initiate some variables
		$more_requested = false;
		$number_of_words = 0;
		$raw_excerpt = $panache_excerpt;

		if ( '' == $panache_excerpt ) {
			
			$panache_excerpt = get_the_content('');
			// detect if a more link was in the post so the Read More button can be displayed
			if( strpos($post->post_content, '<!--more-->') !== false ){ $more_requested = true; }
			//if( '' != $post->post_excerpt ){ $more_requested = true; }
			//print_r( 'yes' );
			
			//$panache_excerpt = strip_shortcodes( $panache_excerpt );
			$panache_excerpt = do_shortcode( $panache_excerpt);
			$panache_excerpt = apply_filters('the_content', $panache_excerpt);
			$panache_excerpt = str_replace(']]>', ']]&gt;', $panache_excerpt);
			$panache_excerpt = strip_tags($panache_excerpt, panache_allowed_excerpt_tags()); /*IF you need to allow just certain tags. Delete if all tags are allowed */

			//Set the excerpt word count and only break after sentence is complete.
			$excerpt_word_count = 30;
			$excerpt_length = apply_filters('excerpt_length', $excerpt_word_count); 
			$tokens = array();
			$excerptOutput = '';
			$count = 0;

			// Divide the string into tokens; HTML tags, or words, followed by any whitespace
			preg_match_all('/(<[^>]+>|[^<>\s]+)\s*/u', $panache_excerpt, $tokens);

			foreach ($tokens[0] as $token) { 

				if ($count >= $excerpt_word_count && preg_match('/[\,\;\?\.\!]\s*$/uS', $token) && $token != '' ) { 
					// Limit reached, continue until , ; ? . or !occur at the end
					$excerptOutput .= trim($token);
					$number_of_words = $count;
					break;
				}

				// Add words to complete sentence
				$count++;

				// Append what's left of the token
				$excerptOutput .= $token;
				
			}

            $panache_excerpt = trim(force_balance_tags($excerptOutput));
			
			$excerpt_end = '<a class="ka-read-more" href="'. get_permalink( get_the_ID() ) . '">' . '<span class="read-more-button">' . __('Read More' , 'panache') . '<i class="fa fa-long-arrow-right"></i></span></a>';
			//$excerpt_end = ' <a href="'. esc_url( get_permalink() ) . '">' . '&nbsp;&raquo;&nbsp;' . sprintf(__( 'Read more about: %s &nbsp;&raquo;', 'wpse' ), get_the_title()) . '</a>'; 
			$excerpt_more = apply_filters('excerpt_more', ' ' . $excerpt_end); 
			
			$pos = strrpos($panache_excerpt, '</');
			if( $number_of_words > $excerpt_word_count || $more_requested == true ){
				 //if ($pos !== false) {
					// Inside last HTML tag
					//$panache_excerpt = substr_replace($panache_excerpt, $excerpt_end, $pos, 0); /* Add read more next to last word */
				//} else {
					// After the content
					$panache_excerpt .= $excerpt_end; /*Add read more in new paragraph */
				//}
			}
			//$panache_excerpt = apply_filters('the_content', $panache_excerpt);
			return $panache_excerpt;   

		} else {
			
			// in this case the excerpt is defined and a more tag is needed
			$excerpt_end = '<a class="ka-read-more" href="'. get_permalink( get_the_ID() ) . '">' .'<span class="read-more-button">'. __('Read More' , 'panache') . '<i class="fa fa-long-arrow-right"></i></span></a>';
			$panache_excerpt = $panache_excerpt.''.$excerpt_end;
			
		}
	return apply_filters('wpse_custom_wp_trim_excerpt', $panache_excerpt, $raw_excerpt);
	}
	remove_filter('get_the_excerpt', 'wp_trim_excerpt');
	add_filter('get_the_excerpt', 'panache_trim_excerpt');
}

/* 
 * Excerpt Password - WordPress Codex - display password form in protected posts
 */
if ( !function_exists( 'panache_excerpt_password_form' ) ) {  
	function panache_excerpt_password_form( $excerpt ) {
	    if ( post_password_required() )
	        $excerpt = get_the_password_form();
	    return $excerpt;
	}
	add_filter( 'the_excerpt', 'panache_excerpt_password_form' );
}