<?php
/**
 * Panache Post Format Image
 *
 * The Image Post Format allows the user to post a feature image and have it 
 * displayed in the content area below the Too Meta Section. The image caption 
 * will be presented as an integral part of the message. If Show Image Meta is 
 * set in the Panache Options => Blog section, then the camera meta for the image 
 * that was uploaded with the image will be displayed. 
 *
 *
 * @package		Panache WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */

$display_post_icon = intval( panache_get_option( 'panache_display_post_icons' ) );
$display_image_meta = intval( panache_get_option( 'panache_display_image_meta' ) );
$use_excerpts = intval( panache_get_option( 'panache_use_excerpts' ) );
?>

<div class="post-wrap-image">
	
	<?php if ( $display_post_icon == 1 ) { ?>
		
		<div class="post-stamp">
			
			<div class="post-stamp-date">
				<span class="post-stamp-date-day"><?php the_time('d'); ?></span>
				<span class="post-stamp-date-month"><?php the_time('M'); ?></span>
				<span class="post-stamp-date-year"><?php the_time('Y'); ?></span>
			</div>
			
			<div class="post-stamp-icon">
				<i class="post-icon-format fa fa-camera" title="Image Post"></i>
			</div>
			
		</div>
	
	<?php } ?>
	
	<div class="post-wrap-image-content">

		<div class="post-header">
			
			<h2 class="post-title entry-title">
				<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
				<?php panache_comments_link(); ?>
			</h2>
		
			<?php panache_post_metatop(); ?>
			
		</div>

		<?php
			//feature image
			if ( has_post_thumbnail() && !post_password_required() ) { ?>
				
				<div class="image-entry entry-content">
					
					<div class="post-format-image">
						<?php the_post_thumbnail('full'); ?>
					</div>
				
					<?php if( $display_image_meta == 1 ) {
						
						echo '<div class="post-format-meta">';
						
							$image_meta = wp_get_attachment_metadata( get_post_thumbnail_id() );
							echo '<span class="">Camera : '.$image_meta['image_meta']['camera'].' | </span>'; 
							echo '<span class="">Width : '.$image_meta['width'].' px | </span>';
							echo '<span class="">Height : '.$image_meta['height'].' px | </span><br/>';
							echo '<span class="">Aperture : '.$image_meta['image_meta']['aperture'].' | </span>';
							echo '<span class="">Focal Length : '.$image_meta['image_meta']['focal_length'].' | </span>';
							if( $image_meta['image_meta']['shutter_speed'] != 0 ) {
								$shutter_speed = 1/$image_meta['image_meta']['shutter_speed'];
							} else {
								$shutter_speed = '';
							}
							echo '<span class="">Shutter Speed : '.$image_meta['image_meta']['iso'].'</span>';
						
						echo '</div>';
						
					}
				
					if( get_post(get_post_thumbnail_id())->post_excerpt != '' )	{
						echo '<div class="display-image-caption">';
							echo '<h2>'.get_post(get_post_thumbnail_id())->post_excerpt.'</h2>';		
						echo '</div>';
						
					}

					if( get_post(get_post_thumbnail_id())->post_content != '' )	{
						echo '<div class="display-image-content">';
							echo get_post(get_post_thumbnail_id())->post_content;		
						echo '</div>';
						
					} ?>
					
				</div>
				
			<?php } ?>
		
		<div class="image-post-content">
			<?php 
				if( $use_excerpts == true && !is_single() ) {
					the_excerpt();
				} else {
					the_content(__('Read more','panache'));  
				}
			?>
		</div>
		
		<?php panache_post_metabottom( 'image' ); ?>
		
	</div>
	
</div>