<?php
/*
Plugin Name: Panache Category Widget
Plugin URI: http://kevinsspace.ca/demo3/
Description: A widget for the Panache Theme that allows the user to remove categories from the list
Version: 1.1
Author: Kevin Archibald
Author URI: http://kevinsspace.ca/
License: GPLv3
 */
 
/**
 * Panache Category Widget
 *
 * This file is a widget was modified from the WordPress Category Widget
 *
 * @package		Panache WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
/**
 * Categories widget class
 *
 * @since 2.8.0
 */
// use widgets_init action hook to execute custom function
 add_action ( 'widgets_init','panache_register_category_widget' );
 
//register our widget 
function panache_register_category_widget() {
	register_widget ( 'panache_category_widget' );
}
  
class panache_category_widget extends WP_Widget {

	//process the new widget
    public function __construct() {
        $widget_ops = array( 
			'classname' => 'panache_category_widget_class', 
			'description' => __('Display selected categories','panache') 
			); 
        parent::__construct( 'panache_category_widget', __('Panache Category Widget','panache'), $widget_ops );
    }
	
	public function form( $instance ) {
		
		//Defaults
		$panache_category_defaults = array(
 			'panache_title' => __('Categories','panache'),
 			'panache_count' => 0,
 			'panache_hierarchical' => 0,
 			'panache_dropdown' => 0,
 			'panache_exclude_ids' => ''
		);
		
		$instance = wp_parse_args( (array) $instance, $panache_category_defaults );
		
		$title = esc_attr( $instance['panache_title'] );
		$count = $instance['panache_count'];
		$hierarchical = $instance['panache_hierarchical'];
		$dropdown =  $instance['panache_dropdown'];
		$exclude_ids = esc_attr( $instance['panache_exclude_ids'] );
		
		//validate data
		if( $count != 1 ) $count = 0;
		if( $hierarchical != 1 ) $hierarchical = 0;
		if( $dropdown != 1 ) $dropdown = 0;
		//Validate Exclude list
		$id_picks = array();
		$id_picks = explode( ',', $exclude_ids );
		$counter = 0;
		$filtered_list = '';
		foreach( $id_picks as $pick ) {
			if( intval( $id_picks[$counter] ) > 1 ) {
				$filtered_list .= intval( $id_picks[$counter] ).',';
			}
			$counter++;
		}
		$exclude_ids = trim( $filtered_list , ',');
		
		?>
		
			<p>
				<label for="<?php echo $this->get_field_id('panache_title'); ?>"><?php _e( 'Title:', 'panache' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id('panache_title'); ?>" name="<?php echo $this->get_field_name('panache_title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
	
			<p>
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('panache_dropdown'); ?>" name="<?php echo $this->get_field_name('panache_dropdown'); ?>"<?php checked( $dropdown ); ?> />
				<label for="<?php echo $this->get_field_id('panache_dropdown'); ?>"><?php _e( 'Display as dropdown', 'panache' ); ?></label><br />
	
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('panache_count'); ?>" name="<?php echo $this->get_field_name('panache_count'); ?>"<?php checked( $count ); ?> />
				<label for="<?php echo $this->get_field_id('panache_count'); ?>"><?php _e( 'Show post counts', 'panache' ); ?></label><br />
	
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id('panache_hierarchical'); ?>" name="<?php echo $this->get_field_name('panache_hierarchical'); ?>"<?php checked( $hierarchical ); ?> />
				<label for="<?php echo $this->get_field_id('panache_hierarchical'); ?>"><?php _e( 'Show hierarchy', 'panache' ); ?></label>
			</p>
			<p>
				<input class="widefat" id="<?php echo $this->get_field_id('panache_exclude_ids'); ?>" name="<?php echo $this->get_field_name('panache_exclude_ids'); ?>" type="text" value="<?php echo $exclude_ids; ?>" />
				<label for="<?php echo $this->get_field_id('panache_exclude_ids'); ?>"><?php _e( 'Exclude categories-list id\'s separated by a comma', 'panache' ); ?></label>
			</p>
		
		<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['panache_title'] = strip_tags($new_instance['panache_title']);
		$instance['panache_count'] = !empty($new_instance['panache_count']) ? 1 : 0;
		$instance['panache_hierarchical'] = !empty($new_instance['panache_hierarchical']) ? 1 : 0;
		$instance['panache_dropdown'] = !empty($new_instance['panache_dropdown']) ? 1 : 0;
		$instance['panache_exclude_ids'] = strip_tags($new_instance['panache_exclude_ids']);
		
		return $instance;
	}

	public function widget( $args, $instance ) {
		extract( $args );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Categories' , 'panache' ) : $instance['title'], $instance, $this->id_base );

		$c = ! empty( $instance['panache_count'] ) ? '1' : '0';
		$h = ! empty( $instance['panache_hierarchical'] ) ? '1' : '0';
		$d = ! empty( $instance['panache_dropdown'] ) ? '1' : '0';
		$x = esc_attr($instance['panache_exclude_ids']);

		echo $before_widget;
		if ( $title )
			echo $before_title . $title . $after_title;

		$cat_args = array('orderby' => 'name', 'show_count' => $c, 'hierarchical' => $h, 'exclude' => $x );

		if ( $d ) {
			$cat_args['show_option_none'] = __( 'Select Category' , 'panache' );

			/**
			 * Filter the arguments for the Categories widget drop-down.
			 *
			 * @since 2.8.0
			 *
			 * @see wp_dropdown_categories()
			 *
			 * @param array $cat_args An array of Categories widget drop-down arguments.
			 */
			wp_dropdown_categories( apply_filters( 'widget_categories_dropdown_args', $cat_args ) );
		?>

			<script type='text/javascript'>
			/* <![CDATA[ */
				var dropdown = document.getElementById("cat");
				function onCatChange() {
					if ( dropdown.options[dropdown.selectedIndex].value > 0 ) {
						location.href = "<?php echo home_url(); ?>/?cat="+dropdown.options[dropdown.selectedIndex].value;
					}
				}
				dropdown.onchange = onCatChange;
			/* ]]> */
			</script>

		<?php } else { ?>
			
			<ul>

				<?php
				
					$cat_args['title_li'] = '';

					/**
					 * Filter the arguments for the Categories widget.
					 *
					 * @since 2.8.0
					 *
					 * @param array $cat_args An array of Categories widget options.
					 */
					wp_list_categories( apply_filters( 'widget_categories_args', $cat_args ) );
				?>
				
			</ul>
			
		<?php }

		echo $after_widget;
	}

}
