<?php
/*
Plugin Name: Panache Category Widget
Plugin URI: http://kevinsspace.ca/demo3/
Description: A widget for the Panache Theme that allows the user to remove categories from the list
Version: 1.1
Author: Kevin Archibald
Author URI: http://kevinsspace.ca/
License: GPLv3
 */
 
/**
 * Panache Recent Posts Widget
 *
 * This file is a widget was modified from the WordPress Category Widget
 * see https://wordpress.org/support/topic/recent-posts-widget-with-category-exclude?replies=12
 *
 * @package		Panache WordPress Theme
 * @copyright	Copyright (C) 2015  Kevin Archibald
 * @license		http://www.gnu.org/licenses/quick-guide-gplv3.html  GNU Public License
 * @author		Kevin Archibald <www.kevinsspace.ca/contact/>
 */
/**
 * Recent_Posts widget w/ category exclude class
 * This allows specific Category IDs to be removed from the Sidebar Recent Posts list
 *
 */
// use widgets_init action hook to execute custom function
 add_action ( 'widgets_init','panache_register_recent_posts_widget' );
 
//register our widget 
function panache_register_recent_posts_widget() {
	register_widget ( 'panache_recent_posts_widget' );
}
class panache_recent_posts_widget extends WP_Widget {

	//process the new widget
    public function __construct() {
        $widget_ops = array( 
			'classname' => 'panache_recent_posts', 
			'description' => __('Display recent posts, allow excluded categories','panache') 
		); 
		parent::__construct( 'panache_recent_posts_widget', __('Panache Recent Posts Widget','panache'), $widget_ops );
    }
	
	public function form( $instance ) {
		
		//Defaults
		$panache_recent_posts_defaults = array(
			'panache_title' => __('Recent Posts','panache'),
			'panache_count' => 5,
			'panache_exclude_ids' => ''
		);
		
		$instance = wp_parse_args( (array) $instance, $panache_recent_posts_defaults );
		
		$title = esc_attr( $instance['panache_title'] );
		$count = $instance['panache_count'];
		$exclude_ids = esc_attr( $instance['panache_exclude_ids'] );
		
		//validate data
		$count = is_int( $count ) ? $count : 5;
		//Validate Exclude list
		$id_picks = array();
		$id_picks = explode( ',', $exclude_ids );
		$filtered_list = '';
		$counter = 0;
		foreach( $id_picks as $pick ) {
			if( intval( $id_picks[$counter] ) > 1 ) {
				$filtered_list .= intval( $id_picks[$counter] ).',';
			}
			$counter++;
		}
		$exclude_ids = trim( $filtered_list , ',');
		
		?>

		<p><label for="<?php echo $this->get_field_id('panache_title'); ?>"><?php _e('Title:','panache'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('panache_title'); ?>" name="<?php echo $this->get_field_name('panache_title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('panache_count'); ?>"><?php _e('Number of posts to show:','panache'); ?></label>
		<input id="<?php echo $this->get_field_id('panache_count'); ?>" name="<?php echo $this->get_field_name('panache_count'); ?>" type="text" value="<?php echo $count; ?>" size="3" /></p>

		<p>
			<label for="<?php echo $this->get_field_id('panache_exclude_ids'); ?>"><?php _e( 'Exclude Category(s):','panache' ); ?></label>
			<input type="text" value="<?php echo $exclude_ids; ?>" name="<?php echo $this->get_field_name('panache_exclude_ids'); ?>" id="<?php echo $this->get_field_id('panache_exclude_ids'); ?>" class="widefat" />
			<br />
			<small><?php _e( 'Category IDs, separated by commas','panache' ); ?></small>
		</p>
		
		<?php
	}
	
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['panache_title'] = strip_tags($new_instance['panache_title']);
		$instance['panache_count'] = !empty($new_instance['panache_count']) ? $new_instance['panache_count'] : 5;
		$instance['panache_exclude_ids'] = strip_tags($new_instance['panache_exclude_ids']);
		
		return $instance;
	}

	public function widget( $args, $instance ) {
		
		extract( $args );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Recent Posts' , 'panache' ) : $instance['title'], $instance, $this->id_base );
		
		$c = ! empty( $instance['panache_count'] ) ? $instance['panache_count'] : 5;
		
		$exclude_ids = esc_attr($instance['panache_exclude_ids']);
		$id_picks = array();
		$id_picks = explode( ',', $exclude_ids );
		$filtered_list = '';
		$counter = 0;
		foreach( $id_picks as $pick ) {
			if( intval( $id_picks[$counter] ) > 1 ) {
				$filtered_list .= '-'.intval( $id_picks[$counter] ).',';
			}
			$counter++;
		}
		$exclude_ids = trim( $filtered_list , ',');
		$x = "'".$exclude_ids."'";

		echo $before_widget;
		if ( $title )
			echo $before_title . $title . $after_title;

		$args = array( 'numberposts' => $c, 'category' => $x, 'post_status' => 'publish' );

		$recent_posts = wp_get_recent_posts( $args );
		
		?>
		<ul>
			<?php 
				foreach( $recent_posts as $recent ){
					echo '<li><a href="' . get_permalink($recent["ID"]) . '">' . $recent["post_title"].'</a> </li> ';
				} 
			?>
		</ul>
			
		<?php

		echo $after_widget;
	}
}